@@ -22,9 +22,10 @@ use crate::{
     ext::xmpfr::{self, OptFloat},
     float::{Round, SmallFloat},
     ops::{
-        AddAssignRound, AddFrom, AddFromRound, AssignRound, DivAssignRound, DivFrom, DivFromRound,
-        MulAssignRound, MulFrom, MulFromRound, NegAssign, Pow, PowAssign, PowAssignRound, PowFrom,
-        PowFromRound, RemAssignRound, RemFrom, RemFromRound, SubAssignRound, SubFrom, SubFromRound,
+        AddAssignRound, AddFrom, AddFromRound, AssignRound, CompleteRound, DivAssignRound, DivFrom,
+        DivFromRound, MulAssignRound, MulFrom, MulFromRound, NegAssign, Pow, PowAssign,
+        PowAssignRound, PowFrom, PowFromRound, RemAssignRound, RemFrom, RemFromRound,
+        SubAssignRound, SubFrom, SubFromRound,
     },
     Float,
 };
@@ -77,7 +78,7 @@ impl AssignRound<NegIncomplete<'_>> for Float {
 }
 
 arith_binary_self_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::add;
     Add { add }
     AddAssign { add_assign }
@@ -87,7 +88,7 @@ arith_binary_self_round! {
     AddIncomplete
 }
 arith_binary_self_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::sub;
     Sub { sub }
     SubAssign { sub_assign }
@@ -97,7 +98,7 @@ arith_binary_self_round! {
     SubIncomplete
 }
 arith_binary_self_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::mul;
     Mul { mul }
     MulAssign { mul_assign }
@@ -107,7 +108,7 @@ arith_binary_self_round! {
     MulIncomplete
 }
 arith_binary_self_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::div;
     Div { div }
     DivAssign { div_assign }
@@ -117,7 +118,7 @@ arith_binary_self_round! {
     DivIncomplete
 }
 arith_binary_self_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::fmod;
     Rem { rem }
     RemAssign { rem_assign }
@@ -127,7 +128,7 @@ arith_binary_self_round! {
     RemIncomplete
 }
 arith_binary_self_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::pow;
     Pow { pow }
     PowAssign { pow_assign }
@@ -139,7 +140,7 @@ arith_binary_self_round! {
 
 #[cfg(feature = "integer")]
 arith_commut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::add_z;
     Add { add }
     AddAssign { add_assign }
@@ -151,7 +152,7 @@ arith_commut_round! {
 }
 #[cfg(feature = "integer")]
 arith_noncommut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::sub_z, xmpfr::z_sub;
     Sub { sub }
     SubAssign { sub_assign }
@@ -164,7 +165,7 @@ arith_noncommut_round! {
 }
 #[cfg(feature = "integer")]
 arith_commut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::mul_z;
     Mul { mul }
     MulAssign { mul_assign }
@@ -176,7 +177,7 @@ arith_commut_round! {
 }
 #[cfg(feature = "integer")]
 arith_noncommut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::div_z, xmpfr::z_div;
     Div { div }
     DivAssign { div_assign }
@@ -189,7 +190,7 @@ arith_noncommut_round! {
 }
 #[cfg(feature = "integer")]
 arith_forward_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::pow_z;
     Pow { pow }
     PowAssign { pow_assign }
@@ -200,7 +201,7 @@ arith_forward_round! {
 
 #[cfg(feature = "rational")]
 arith_commut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::add_q;
     Add { add }
     AddAssign { add_assign }
@@ -212,7 +213,7 @@ arith_commut_round! {
 }
 #[cfg(feature = "rational")]
 arith_noncommut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::sub_q, xmpfr::q_sub;
     Sub { sub }
     SubAssign { sub_assign }
@@ -225,7 +226,7 @@ arith_noncommut_round! {
 }
 #[cfg(feature = "rational")]
 arith_commut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::mul_q;
     Mul { mul }
     MulAssign { mul_assign }
@@ -237,7 +238,7 @@ arith_commut_round! {
 }
 #[cfg(feature = "rational")]
 arith_noncommut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::div_q, xmpfr::q_div;
     Div { div }
     DivAssign { div_assign }
@@ -250,7 +251,7 @@ arith_noncommut_round! {
 }
 
 arith_prim_commut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     PrimOps::add;
     Add { add }
     AddAssign { add_assign }
@@ -271,7 +272,7 @@ arith_prim_commut_round! {
     f64, AddF64Incomplete;
 }
 arith_prim_noncommut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     PrimOps::sub, PrimOps::sub_from;
     Sub { sub }
     SubAssign { sub_assign }
@@ -292,7 +293,7 @@ arith_prim_noncommut_round! {
     f64, SubF64Incomplete, SubFromF64Incomplete;
 }
 arith_prim_commut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     PrimOps::mul;
     Mul { mul }
     MulAssign { mul_assign }
@@ -313,7 +314,7 @@ arith_prim_commut_round! {
     f64, MulF64Incomplete;
 }
 arith_prim_noncommut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     PrimOps::div, PrimOps::div_from;
     Div { div }
     DivAssign { div_assign }
@@ -334,7 +335,7 @@ arith_prim_noncommut_round! {
     f64, DivF64Incomplete, DivFromF64Incomplete;
 }
 arith_prim_noncommut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     PrimOps::rem, PrimOps::rem_from;
     Rem { rem }
     RemAssign { rem_assign }
@@ -355,7 +356,7 @@ arith_prim_noncommut_round! {
     f64, RemF64Incomplete, RemFromF64Incomplete;
 }
 arith_prim_noncommut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     PrimOps::pow, PrimOps::pow_from;
     Pow { pow }
     PowAssign { pow_assign }
@@ -377,35 +378,35 @@ arith_prim_noncommut_round! {
 }
 
 arith_prim_exact_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::shl_u32;
     Shl { shl }
     ShlAssign { shl_assign }
     u32, ShlU32Incomplete;
 }
 arith_prim_exact_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::shr_u32;
     Shr { shr }
     ShrAssign { shr_assign }
     u32, ShrU32Incomplete;
 }
 arith_prim_exact_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::shl_i32;
     Shl { shl }
     ShlAssign { shl_assign }
     i32, ShlI32Incomplete;
 }
 arith_prim_exact_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     xmpfr::shr_i32;
     Shr { shr }
     ShrAssign { shr_assign }
     i32, ShrI32Incomplete;
 }
 mul_op_commut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     add_mul;
     Add { add }
     AddAssign { add_assign }
@@ -416,7 +417,7 @@ mul_op_commut_round! {
     AddMulIncomplete
 }
 mul_op_noncommut_round! {
-    Float, Round, Round::Nearest, Ordering;
+    Float, u32, Round, Round::Nearest, Ordering;
     sub_mul, mul_sub;
     Sub { sub }
     SubAssign { sub_assign }
